=========
 Credits
=========

* William Morgan, for creating Ditz_ in the first place.
* Stuart Langridge, for sorttable_.

.. _Ditz: http://ditz.rubyforge.org
.. _sorttable: http://www.kryogenix.org/code/browser/sorttable
